@@ -17,16 +17,6 @@
 package org.apache.streampark.flink.deployment
 
 import org.apache.flink.kubernetes.kubeclient.FlinkKubeClient
-import org.apache.flink.kubernetes.kubeclient.resources.KubernetesService
-import org.apache.flink.kubernetes.kubeclient.resources.KubernetesService.ServiceType
-
-import java.util.Optional
 
 class FlinkKubernetesClient(kubeClient: FlinkKubeClient)
-  extends FlinkKubernetesClientTrait(kubeClient) {
-
-  override def getService(serviceName: String): Optional[KubernetesService] = {
-    kubeClient.getService(ServiceType.REST_SERVICE, serviceName)
-  }
-
-}
+  extends FlinkKubernetesClientTrait(kubeClient) {}
