@@ -14,9 +14,23 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
+
 package org.apache.streampark.flink.deployment
 
 import org.apache.flink.yarn.YarnClusterDescriptor
+import org.apache.hadoop.fs.Path
+
+import java.io.File
+import java.util
+
+import scala.collection.JavaConversions._
 
 class YarnClusterDescriptorWrapper(yarnClusterDescriptor: YarnClusterDescriptor)
-  extends YarnClusterDescriptorTrait(yarnClusterDescriptor)
+  extends YarnClusterDescriptorTrait(yarnClusterDescriptor) {
+
+  override def addShipFiles(input: util.List[File]): Unit = {
+    val list = new util.ArrayList[Path]()
+    input.foreach(x => list.add(new Path(x.toURI)))
+    yarnClusterDescriptor.addShipFiles(list)
+  }
+}
